from os import path
from pathlib import Path
from flask import Flask, render_template
from flask_frozen import Freezer

# Define the path to the templates folder
template_folder = path.abspath('./wiki')

app = Flask(__name__, template_folder=template_folder)
app.config['FREEZER_DESTINATION'] = 'public'
app.config['FREEZER_RELATIVE_URLS'] = True
app.config['FREEZER_IGNORE_MIMETYPE_WARNINGS'] = True
freezer = Freezer(app)

@app.cli.command()
def freeze():
    freezer.freeze()

@app.cli.command()
def serve():
    freezer.run()

# Route for the homepage
@app.route('/')
def home():
    return render_template('pages/home.html')

# Route to dynamically serve pages
@app.route('/<page>')
def page_handler(page):
    # Correct the path handling here
    page_path = Path(template_folder, 'pages', f'{page.lower()}.html')
    
    if page_path.exists():
        return render_template(f'pages/{page.lower()}.html')
    else:
        return "Page not found", 404

# Main function
if __name__ == "__main__":
    app.run(port=8080)

